@@ -47,17 +47,17 @@ from .utils import ONVIFWSDL, ZeepPatcher, XMLCapturePlugin
 class ONVIFClient:
     def __init__(
         self,
-        host,
-        port,
-        username,
-        password,
-        timeout=10,
-        cache=CacheMode.ALL,
-        use_https=False,
-        verify_ssl=True,
-        apply_patch=True,
-        capture_xml=False,
-        wsdl_dir=None,
+        host: str,
+        port: int,
+        username: str,
+        password: str,
+        timeout: int = 10,
+        cache: CacheMode = CacheMode.ALL,
+        use_https: bool = False,
+        verify_ssl: bool = True,
+        apply_patch: bool = True,
+        capture_xml: bool = False,
+        wsdl_dir: str = None,
     ):
         # Apply or remove zeep patch based on user preference
         if apply_patch:
@@ -95,7 +95,7 @@ class ONVIFClient:
         # Try to retrieve device services and create namespace -> XAddr mapping
         self.services = None
         self._service_map = {}
-        
+
         # Temporary variable to hold capabilities
         self.capabilities = None
 
@@ -241,7 +241,8 @@ class ONVIFClient:
                         svc = getattr(ext, service_path, None)
                         xaddr = getattr(svc, "XAddr", None) if svc else None
                     else:
-                        # Step 3: try capabilities.Extension.Extension.service_path (e.g. capabilities.Extension.Extension.Provisioning)
+                        # Step 3: try capabilities.Extension.Extension.service_path
+                        # (e.g. capabilities.Extension.Extension.Provisioning)
                         ext_ext = getattr(ext, "Extension", None)
                         if ext_ext and hasattr(ext_ext, service_path):
                             svc = getattr(ext_ext, service_path, None)
@@ -299,7 +300,7 @@ class ONVIFClient:
                 xaddr = addr_obj["_value_1"]
             elif hasattr(addr_obj, "_value_1"):
                 xaddr = addr_obj._value_1
-            
+
             xaddr = self._rewrite_xaddr_if_needed(xaddr)
         except Exception:
             pass
@@ -308,10 +309,10 @@ class ONVIFClient:
             raise RuntimeError(
                 "SubscriptionReference.Address missing in subscription response"
             )
-        
+
         if xaddr not in self._pullpoints:
             self._pullpoints[xaddr] = PullPoint(xaddr=xaddr, **self.common_args)
-        
+
         return self._pullpoints[xaddr]
 
     def notification(self):
@@ -329,7 +330,7 @@ class ONVIFClient:
                 xaddr = addr_obj["_value_1"]
             elif hasattr(addr_obj, "_value_1"):
                 xaddr = addr_obj._value_1
-            
+
             xaddr = self._rewrite_xaddr_if_needed(xaddr)
         except Exception:
             pass
@@ -338,10 +339,10 @@ class ONVIFClient:
             raise RuntimeError(
                 "SubscriptionReference.Address missing in subscription response"
             )
-        
+
         if xaddr not in self._subscriptions:
             self._subscriptions[xaddr] = Subscription(xaddr=xaddr, **self.common_args)
-        
+
         return self._subscriptions[xaddr]
 
     # Imaging
